<?php
/* 
 * Plugin Name:   Different Posts Per Page
 * Version:       1.7.6
 * Plugin URI:    http://www.maxblogpress.com/plugins/dppp/
 * Description:   Show different number of posts in home, category, search or archive page. Adjust your settings <a href="options-general.php?page=different-posts-per-page/diff-posts-per-page.php">here</a>.
 * Author:        MaxBlogPress
 * Author URI:    http://www.maxblogpress.com
 *
 * License:       GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 * Copyright (C) 2007 www.maxblogpress.com
 * 
 */
 
define('DPPP_NAME', 'Different Posts Per Page');  // Name of the Plugin
define('DPPP_VERSION', '1.7.6');	              // Current version of the Plugin
 
/**
 * DPPP - Different Posts Per Page Class
 * Holds all the necessary functions and variables
 */
class DPPP 
{
    /**
     * Different posts per page plugin path
     * @var string
     */
	var $dppp_path    = "";
	
    /**
     * Different posts per page values set by admin
     * @var array
     */
	var $dppp_values  = array();
	
    /**
     * Options available in different posts per page values
     * @var array
     */
	var $dppp_option  = array();
	
    /**
     * Parsed query string variables are stored in this array
     * @var array
     */
	var $dppp_qvars   = array();
	
    /**
     * Holds the post/page type. If its home, single, archive, etc.
     * @var string
     */
	var $dppp_pg_type = "";
	
    /**
     * Holds post category
     * @var string
     */
	var $dppp_cat     = "";
	
    /**
     * Holds query string
     * @var string
     */
	var $dppp_qstr    = "";
	
    /**
     * Holds Post/Get data
     * @var array
     */
	var $dppp_request    = array();
	
    /**
     * Holds wordpress version
     * @var string
     */
	var $dppp_wp_version = "";
	
    /**
     * Holds the default 'posts per page' values
	 * These values will be set while activating the plugin
     * @var array
     */
	var	$default_options = array(
								'is_home' => array(
									'posts_per_page' => 5,
									'what_to_show'   => 'posts',
									'orderby'        => 'date',
									'order'          => 'DESC'
								),
								'is_category' => array(
									'posts_per_page' => 5,
									'what_to_show'   => 'posts',
									'orderby'        => 'date',
									'order'          => 'DESC'
								),
								'is_archive' => array(
									'posts_per_page' => 5,
									'what_to_show'   => 'posts',
									'orderby'        => 'date',
									'order'          => 'DESC'
								),
								'is_search' => array(
									'posts_per_page' => 5,
									'what_to_show'   => 'posts',
									'orderby'        => 'date',
									'order'          => 'DESC'
								),
								'is_tag' => array(
									'posts_per_page' => 5,
									'what_to_show'   => 'posts',
									'orderby'        => 'date',
									'order'          => 'DESC'
								)
							);

    /**
     * Holds the various pages available in wordpress
     * @var array
     */
	var $dppp_pages      = array('is_home'=>'Home', 'is_category'=>'Category', 'is_archive'=>'Archive', 'is_search'=>'Search', 
								'is_author'=>'Author', 'is_paged'=>'Paged', 'is_feed'=>'Feed', 'is_date'=>'Date', 
								'is_year'=>'Year', 'is_month'=>'Month', 'is_day'=>'Day', 'is_time'=>'Time', 'is_tag'=>'Tag');			
	var $dppp_shows      = array('posts');
	var $dppp_orderby    = array('date');
	var $dppp_orders     = array('DESC', 'ASC');

	
	/**
	 * Constructor. Add DPPP plugin actions/filters and gets the user defined options.
	 * @access public
	 */
	function DPPP() {
		global $wp_version;
		$this->dppp_wp_version = $wp_version;
		$default_posts_per_page = get_option("posts_per_page");
		$this->default_options[is_home][posts_per_page] 	= $default_posts_per_page;
		$this->default_options[is_category][posts_per_page] = $default_posts_per_page;
		$this->default_options[is_archive][posts_per_page] 	= $default_posts_per_page;
		$this->default_options[is_search][posts_per_page] 	= $default_posts_per_page;
		$this->default_options[is_tag][posts_per_page]      = $default_posts_per_page;

		$this->dppp_path     = preg_replace('/^.*wp-content[\\\\\/]plugins[\\\\\/]/', '', __FILE__);
		$this->dppp_path     = str_replace('\\','/',$this->dppp_path);
		$this->dppp_siteurl  = get_bloginfo('wpurl');
		$this->dppp_siteurl  = (strpos($this->dppp_siteurl,'http://') === false) ? get_bloginfo('siteurl') : $this->dppp_siteurl;
		$this->dppp_fullpath = $this->dppp_siteurl.'/wp-content/plugins/'.substr($this->dppp_path,0,strrpos($this->dppp_path,'/')).'/';
		$this->dppp_abspath  = str_replace("\\","/",ABSPATH); 
		$this->img_how       = '<img src="'.$this->dppp_fullpath.'images/how.gif" border="0" align="absmiddle">';
		$this->img_comment   = '<img src="'.$this->dppp_fullpath.'images/comment.gif" border="0" align="absmiddle">';
		
	    add_action('activate_'.$this->dppp_path, array(&$this, 'dpppActivate'));
		add_action('admin_menu', array(&$this, 'dpppAddMenu'));
		
		$this->dppp_activate = get_option('dppp_activate');
		if( !$this->dppp_values = get_option('diff_posts_per_page') ) {
			$this->dppp_values = array();
		}
		
		if ( $this->dppp_activate == 2 ) {
			add_filter('query_string', array(&$this, 'dpppCustomQuery'));
			if ( 
			$this->dppp_values['is_home']['posts_per_page'] > 0 && $this->dppp_values['is_paged']['posts_per_page'] > 0 && 
			($this->dppp_values['is_home']['posts_per_page'] != $this->dppp_values['is_paged']['posts_per_page']) 
			) {
				$this->dppp_the_diff = intval($this->dppp_values['is_paged']['posts_per_page'] - $this->dppp_values['is_home']['posts_per_page']);
				add_filter('post_limits', array(&$this, 'dpppAlterLimits'));
			}
		}
	}
	
	/**
	 * Called when plugin is activated. Adds option_value to the options table.
	 * @access public
	 */
	function dpppActivate() {
		add_option('dppp_activate', 0);
		add_option('diff_posts_per_page', $this->default_options, 'Different posts per page plugin options', 'no');
		return true;
	}
	
	/**
	 * Make changes in the Lower Limit in the LIMIT portion of the query string.
	 * Required if admin has set 'posts_per_page' for is_paged.
	 * Solves the problem of some posts not being displayed.
	 * @param string $limits
	 * @return string $limits
	 * @access public
	 */
	function dpppAlterLimits($limits) {
		if ( trim($limits) ) {
			$dppp_limits_arr = explode(",",trim(strstr(trim($limits), " ")));
			$dppp_limit_from = trim($dppp_limits_arr[0]);
			$dppp_limit_to   = trim($dppp_limits_arr[1]);
			if ( $dppp_limit_from > 0 ) {
				$dppp_limit_from = $dppp_limit_from - $this->dppp_the_diff;
				$limits = " LIMIT ".$dppp_limit_from.", ".$dppp_limit_to;
			}
		}
		return $limits;
	}
	
	/**
	 * Adds user defined query options to the main query string
	 * Rebuilds the query string
	 * @param string $query_string The main query string
	 * @return string The custom query string
	 * @access public
	 */
	function dpppCustomQuery($query_string) {
		$query_str = $query_string;
		parse_str($query_str, $qvars);
		$this->dppp_qstr  = $query_str;
		$this->dppp_qvars = $qvars;
		if ( $this->dppp_values ) {
			$this->dpppGetPageType();
			$this->dpppGetCategory();
		}
		if ( $this->dppp_cat ) {
			$this->dppp_option = $this->dppp_values[$this->dppp_cat];
		} else if ( $this->dppp_pg_type ) {
			$this->dppp_option = $this->dppp_values[$this->dppp_pg_type];
		}
		if ( $this->dppp_option ) {
			$dppp_query_str = array(
				'posts_per_page' => $this->dppp_option['posts_per_page'],
				'what_to_show'   => $this->dppp_option['what_to_show'],
				'orderby'        => $this->dppp_option['orderby'],
				'order'          => $this->dppp_option['order']
				);
			$this->dppp_qvars = array_merge($dppp_query_str,$this->dppp_qvars);
			foreach ( $this->dppp_qvars as $key=>$val ) {
				$queryvars[] = $key.'='.$val;
			}
			$this->dppp_qstr = implode('&', $queryvars);
		}
		return $this->dppp_qstr;
	}
	
	/**
	 * Determines the page type.
	 * Archive page => Author, Category, Date
	 * Date => Time, Day, Month, Year
	 * @access public 
	 */
	function dpppGetPageType() {
		global $wp_query;
		$wp_query->parse_query($this->dppp_qstr);

		if ( $wp_query->is_feed AND $this->dppp_values['is_feed'] ) {
			$this->dppp_pg_type = 'is_feed';
		} else if ( $wp_query->is_paged AND $this->dppp_values['is_paged'] ) {
			$this->dppp_pg_type = 'is_paged';
		} else if ( $wp_query->is_tag AND $this->dppp_values['is_tag'] ) {
			$this->dppp_pg_type = 'is_tag';
		} else if ( $wp_query->is_archive ) {
			if ( $wp_query->is_author AND $this->dppp_values['is_author'] ) {
				$this->dppp_pg_type = 'is_author';
			} else if ( $wp_query->is_category AND $this->dppp_values['is_category'] ) {
				$this->dppp_pg_type = 'is_category';
			} else if ( $wp_query->is_date ) {
				if ( $wp_query->is_time AND $this->dppp_values['is_time'] ) {
					$this->dppp_pg_type = 'is_time';
				} else if ( $wp_query->is_day AND $this->dppp_values['is_day'] ) {
					$this->dppp_pg_type = 'is_day';
				} else if ( $wp_query->is_month AND $this->dppp_values['is_month'] ) {
					$this->dppp_pg_type = 'is_month';
				} else if ( $wp_query->is_year AND $this->dppp_values['is_year'] ) {
					$this->dppp_pg_type = 'is_year';
				} else if ( $this->dppp_values['is_date'] ) {
					$this->dppp_pg_type = 'is_date';
				} else if ( $this->dppp_values['is_archive'] ) {
					$this->dppp_pg_type = 'is_archive';
				}
			}
		} else if ( $wp_query->is_search AND $this->dppp_values['is_search'] ) {
			$this->dppp_pg_type = 'is_search';
		} else if ( function_exists(is_tag) AND is_tag() AND $this->dppp_values['is_tag'] ) {
			$this->dppp_pg_type = 'is_tag';		
		} else if ( $wp_query->is_home AND $this->dppp_values['is_home'] ) {
			$this->dppp_pg_type = 'is_home';
		}
	}
	
	/**
	 * Get the category id from category nice_name.
	 * @access public 
	 */
	function dpppGetCategory() {
		global $wp_query;
		global $wpdb;
		
		if ( $wp_query->is_category ) {
			if ( !($category_id = $wp_query->get('cat')) ) {
				$category    = $wp_query->get('category_name');
				if ( $this->dppp_wp_version < 2.3 ) {
					$sqlstr  = "SELECT cat_ID FROM $wpdb->categories WHERE category_nicename = '". $wpdb->escape($category) ."'";
				} else {
					$sqlstr  = "SELECT term_id FROM $wpdb->terms WHERE slug = '". $wpdb->escape($category) ."'";
				}
				$category_id = (int) $wpdb->get_var($sqlstr);
			}
			if ( $this->dppp_values['cat_'.$category_id] ) {
				$this->dppp_cat = 'cat_'.$category_id;
			}
		}
	}
	
	/**
	 * Get the category_nicename from category id
	 * @param int $catid Category Id.
	 * @return string Category nicename.
	 * @access public 
	 */
	function dpppGetCategoryNicename($catid) {
		global $wpdb;
		if ( $this->dppp_wp_version < 2.3 ) {
			$sqlstr  = "SELECT category_nicename FROM $wpdb->categories WHERE cat_ID = '". $wpdb->escape((int) $catid) ."'";
		} else {
			$sqlstr  = "SELECT name FROM $wpdb->terms WHERE term_id = '". $wpdb->escape((int) $catid) ."'";
		}
		return $wpdb->get_var($sqlstr);
	}
	
	/**
	 * Adds "DiffPostsPerPage" link to admin Options menu
	 * @access public 
	 */
	function dpppAddMenu() {
		add_options_page('Different Posts Per Page', 'DiffPostsPerPage', 'manage_options', $this->dppp_path, array(&$this, 'dpppOptionsPg'));
	}
	
	/**
	 * Displays the page content for "DiffPostsPerPage" Options submenu
	 * Carries out all the operations in Options page
	 * @access public 
	 */
	function dpppOptionsPg() {
		load_plugin_textdomain('DiffPostsPerPage');
		$this->dppp_request = $_REQUEST['dppp'];
		
		$form_1 = 'dppp_reg_form_1';
		$form_2 = 'dppp_reg_form_2';
		// Activate the plugin if email already on list
		if ( trim($_GET['mbp_onlist']) == 1 ) { 
			$this->dppp_activate = 2;
			update_option('dppp_activate', $this->dppp_activate);
			$msg = 'Thank you for registering the plugin. It has been activated'; 
		} 
		// If registration form is successfully submitted
		if ( ((trim($_GET['submit']) != '' && trim($_GET['from']) != '') || trim($_GET['submit_again']) != '') && $this->dppp_activate != 2 ) { 
			update_option('dppp_name', $_GET['name']);
			update_option('dppp_email', $_GET['from']);
			$this->dppp_activate = 1;
			update_option('dppp_activate', $this->dppp_activate);
		}
		if ( intval($this->dppp_activate) == 0 ) { // First step of plugin registration
			$this->dpppRegister_1($form_1);
		} else if ( intval($this->dppp_activate) == 1 ) { // Second step of plugin registration
			$name  = get_option('dppp_name');
			$email = get_option('dppp_email');
			$this->dpppRegister_2($form_2,$name,$email);
		} else if ( intval($this->dppp_activate) == 2 ) { // Options page
			if ( $_GET['action'] == 'upgrade' ) {
				$this->dpppUpgradePlugin();
				exit;
			}
			if ( $this->dppp_request['add_pg'] || $this->dppp_request['add_cat'] ) {
				$this->dpppAddOptions();
				$this->dpppShowOptionsPage($msg=1);
			} else if ( $this->dppp_request['delete_checked'] ) {
				$this->dpppDeleteOptions();
				$this->dpppShowOptionsPage($msg=2);
			} else if ( $this->dppp_request['save_all'] ) {
				$this->dpppSaveOptions();
				$this->dpppShowOptionsPage($msg=3);
			} else {
				$this->dpppShowOptionsPage($msg);
			}
		}
	}
	
	/**
	 * Adds and updates 'posts per page' options
	 * @access public 
	 */
	function dpppAddOptions() {
		if ($this->dppp_request['add_cat']) {
			$dppp_options_new = array(
				'cat_'. $_REQUEST['cat'] => array(
					'posts_per_page' => intval($this->dppp_request['category']['posts_per_page']),
					'what_to_show'   => $this->dppp_request['category']['what_to_show'],
					'orderby'        => $this->dppp_request['category']['orderby'],
					'order'          => $this->dppp_request['category']['order']
				));
		}
		else {
			$dppp_options_new = array(
				$this->dppp_request['page'] => array(
					'posts_per_page' => intval($this->dppp_request['posts_per_page']),
					'what_to_show'   => $this->dppp_request['what_to_show'],
					'orderby'        => $this->dppp_request['orderby'],
					'order'          => $this->dppp_request['order']
				));
		}
		$this->dppp_values = array_merge($this->dppp_values, $dppp_options_new);
		update_option('diff_posts_per_page', $this->dppp_values);
	}
	
	/**
	 * Saves the current 'posts per page' options
	 * @access public 
	 */
	function dpppSaveOptions() {
		if ( count($this->dppp_request['option_save']) ) {
			foreach ( $this->dppp_request['option_save'] as $key=>$pg ) {
				$dppp_options_new[$pg] = array(
							'posts_per_page' => intval($this->dppp_request['option_posts_per_page'][$key]),
							'what_to_show'   => 'posts',
							'orderby'        => 'date',
							'order'          => $this->dppp_request['option_order'][$key]
							);
			}
		}
		$this->dppp_values = $dppp_options_new;
		update_option('diff_posts_per_page', $this->dppp_values);
	}
	
	/**
	 * Deletes 'posts per page' options
	 * @access public 
	 */
	function dpppDeleteOptions() {
		if ( count($this->dppp_request['delete']) ) {
			foreach ( $this->dppp_request['delete'] as $pg ) {
				unset($this->dppp_values[$pg]);
			}
		}
		update_option('diff_posts_per_page', $this->dppp_values);
	}
	
	/**
	 * Page Header
	 */
	function dpppHeader() {
		if ( !isset($_GET['dnl']) ) {	
			$dppp_version_chk = $this->dpppRecheckData();
			if ( ($dppp_version_chk == '') || strtotime(date('Y-m-d H:i:s')) > (strtotime($dppp_version_chk['last_checked_on']) + $dppp_version_chk['recheck_interval']*60*60) ) {
				$update_arr = $this->dpppExtractUpdateData();
				if ( count($update_arr) > 0 ) {
					$latest_version   = $update_arr[0];
					$recheck_interval = $update_arr[1];
					$download_url     = $update_arr[2];
					$msg_in_plugin    = $update_arr[3];
					$msg_in_plugin    = $update_arr[4];
					$upgrade_url      = $update_arr[5];
					if( DPPP_VERSION < $latest_version ) {
						$dppp_version_check = array('recheck_interval' => $recheck_interval, 'last_checked_on' => date('Y-m-d H:i:s'));
						$this->dpppRecheckData($dppp_version_check);
						$msg_in_plugin = str_replace("%latest-version%", $latest_version, $msg_in_plugin);
						$msg_in_plugin = str_replace("%plugin-name%", DPPP_NAME, $msg_in_plugin);
						$msg_in_plugin = str_replace("%upgrade-url%", $upgrade_url, $msg_in_plugin);
						$msg_in_plugin = '<div style="border-bottom:1px solid #CCCCCC;background-color:#FFFEEB;padding:6px;font-size:11px;text-align:center">'.$msg_in_plugin.'</div>';
					} else {
						$msg_in_plugin = '';
					}
				}
			}
		}
		echo '<h2>'.DPPP_NAME.' '.DPPP_VERSION.'</h2>';
		if ( trim($msg_in_plugin) != '' && !isset($_GET['dnl']) ) echo $msg_in_plugin;
		echo '<br /><strong>'.$this->img_how.' <a href="http://www.maxblogpress.com/plugins/dppp/use/" target="_blank">How to use it</a>&nbsp;&nbsp;&nbsp;'; 
        echo $this->img_comment.' <a href="http://www.maxblogpress.com/plugins/dppp/comments/" target="_blank">Comments and Suggestions</a></strong><br /><br />';
	}
	
	/**
	 * Page Footer
	 */
	function dpppFooter() {
		echo '<p style="text-align:center;margin-top:3em;"><strong>'.DPPP_NAME.' '.DPPP_VERSION.' by <a href="http://www.maxblogpress.com/" target="_blank" >MaxBlogPress</a></strong></p>';
	}
	
	/**
	 * Display the options page
	 * @param string $msg Update/Delete message to be shown
	 * @access public 
	 */
	function dpppShowOptionsPage($msg=0) {
		if ( $msg==1 || $msg==3 ) {
			$msg = "'posts per page' options saved.";
		} else if ( $msg==2 ) {
			$msg = "'posts per page' options deleted.";
		}
		if ( $msg ) {
			echo '<div id="message" class="updated fade"><p><strong>'. __($msg, 'dppp') .'</strong></p></div>';
		}
		?>
		<script>
		//<!--
		function isNumeric(num){
			var the_val = num.value;
			var ret = (/^-?[0-9]*$/.test(the_val));
			if ( ret == false ) {
				alert('Should be a numeric value');
				num.value = the_val.substr(the_val,the_val.length-1);
				return false;
			}
			return true;
		}
		function toggleAll(parent) {
			var now = parent.checked;
			var frm = document.dpppform;
			var len = frm.elements.length;
			for ( i=0; i<len; i++ ) {
				if ( frm.elements[i].name=='dppp[delete][]' ) {
					frm.elements[i].checked=now;
				}
			}
		}//--></script>
		<style type="text/css">
		table, tbody, tfoot, thead, tr, th, td {
			padding: 3px;
		}</style>
		<form name="dpppform" method="post">
		<div class="wrap">
		 <?php $this->dpppHeader(); ?>
		 <h3><?php _e('Current "posts per page" options', 'dppp'); ?></h3>
		 <table cellspacing="1" cellpadding="3" width="60%" style="border:1px solid #dddddd; padding:0;">
		  <tr>
		   <td style="background-color:#dfdfdf" width="10%"><div align="center"><input type="checkbox" name="checkall" onclick="toggleAll(this)"/></div></td>
		   <td style="background-color:#dfdfdf"><strong><?php _e('Page', 'dppp'); ?></strong></td>
		   <td style="background-color:#dfdfdf" width="20%"><div align="center"><strong><?php _e('Show', 'dppp'); ?></strong></div></td>
		   <td style="background-color:#dfdfdf" width="15%"><div align="center"><strong><?php _e('Order', 'dppp'); ?></strong></div></td>
		  </tr>
	
		<?php
		  $i = 0;
		  foreach ( (array) $this->dppp_values as $thepage => $dppp_option ) {
		     if (strpos($thepage, 'cat_') !== false) {
			   $cat_id    = str_replace('cat_', '', $thepage);
			   $cat_name  = $this->dpppGetCategoryNicename(intval($cat_id));
			   $page_name = substr($cat_name,0,45).' (category)';
		     }
		     else {
			   $page_name = $this->dppp_pages[$thepage];
		     }
			 $bgcol = ($i % 2 != 0) ? '#f1f1f1' : '#ffffff';
			 ?>
		     <tr>
			  <td style="background-color:<?php echo $bgcol;?>"><div align="center"><input type="checkbox" name="dppp[delete][]" value="<?php echo $thepage; ?>" /></div></td>
			  <td style="background-color:<?php echo $bgcol;?>"><?php echo $page_name; ?><input type="hidden" name="dppp[option_save][]" value="<?php echo $thepage; ?>" /></td>
			  <td style="background-color:<?php echo $bgcol;?>"><div align="center"><input type="text" name="dppp[option_posts_per_page][]" value="<?php echo $dppp_option['posts_per_page'];?>" size="2" maxlength="5" onkeyup="isNumeric(this);" /> posts</div></td>
		      <td style="background-color:<?php echo $bgcol;?>"><div align="center"><select name="dppp[option_order][]">
              <?php foreach ($this->dppp_orders as $order) {
			  		$selected='';
			  		if ($dppp_option['order']==$order) $selected='selected';
					echo "<option $selected>$order</option>";
			  } ?>
              </select></div></td>
			 </tr>
		<?php
		    $i++;
		  } // Eof foreach
		?>
		    <tr>
			 <td style="background-color:#ffffff" colspan="4">
				<input type="submit" class="button" name="dppp[save_all]" value="<?php _e('Save All', 'dppp'); ?>" />	 
				<input type="submit" class="button" name="dppp[delete_checked]" value="<?php _e('Delete Checked', 'dppp'); ?>" /></td>
			</tr>
		</table>
	
	    <h3 style="margin-top:4em;"><?php _e('Add more "posts per page" option', 'dppp'); ?></h3>
		<p><?php _e('# Use \'-1\' to show all posts.', 'dppp'); ?></p>
		<table cellspacing="1" cellpadding="3" width="80%" style="border:1px solid #dddddd; padding:0;">
			<tr class="alternate">
				<td style="background-color:#dfdfdf" width="14%">&nbsp;</td>
				<td style="background-color:#dfdfdf"><strong><?php _e('Select', 'dppp'); ?></strong></td>
				<td style="background-color:#dfdfdf" width="15%"><div align="center"><strong><?php _e('Show', 'dppp'); ?></strong></div></td>
				<td style="background-color:#dfdfdf" width="10%"><div align="center"><strong><?php _e('Order', 'dppp'); ?></strong></div></td>
				<td style="background-color:#dfdfdf" width="10%">&nbsp;</td>
			</tr>
			<tr>
				<td style="background-color:#ffffff" scope="row"><?php _e('Page', 'dppp'); ?></td>
				<td style="background-color:#ffffff">
				<select name="dppp[page]">
				<?php
				foreach ($this->dppp_pages as $key=>$val) {
					echo "<option value='".$key."'>$val</option>";
				}
				?>
				</select></td>
				<td style="background-color:#ffffff"><div align="center">
				<input type="text" name="dppp[posts_per_page]" size="3" maxlength="5" onkeyup="isNumeric(this);" /> posts
				<input type="hidden" name="dppp[what_to_show]" value="<?php echo $this->dppp_shows[0];?>" /></div></td>
				<td style="background-color:#ffffff"><div align="center">
				<input type="hidden" name="dppp[orderby]" value="<?php echo $this->dppp_orderby[0];?>" />
				<select name="dppp[order]">
                <?php 
				foreach ($this->dppp_orders as $order) {
					echo "<option>$order</option>";
				}
				?>
                </select></div></td>
				<td style="background-color:#ffffff"><div align="center"><input type="submit" class="button" name="dppp[add_pg]" value="<?php _e('Add', 'dppp'); ?>" /></div></td>
			</tr>
			<tr>
				<td style="background-color:#f1f1f1"><?php _e('Category', 'dppp'); ?></td>
				<td style="background-color:#f1f1f1">
				<?php dropdown_cats(0, 'All', 'ID', 'asc', 0, 0, 0, FALSE, 0, 0) ?></td>
				<td style="background-color:#f1f1f1"><div align="center">
				<input type="text" name="dppp[category][posts_per_page]" size="3" maxlength="5" onkeyup="isNumeric(this);" /> posts
				<input type="hidden" name="dppp[category][what_to_show]" value="<?php echo $this->dppp_shows[0];?>" /></div></td>
				<td style="background-color:#f1f1f1"><div align="center">
				<input type="hidden" name="dppp[category][orderby]" value="<?php echo $this->dppp_orderby[0];?>" />
				<select name="dppp[category][order]">
				<?php 
				foreach ($this->dppp_orders as $order) {
					echo "<option>$order</option>";
				}
				?>
				</select></div></td>
				<td style="background-color:#f1f1f1"><div align="center"><input type="submit" class="button" name="dppp[add_cat]" value="<?php _e('Add', 'dppp'); ?>" /></div></td>
			</tr>
		</table>
		<?php $this->dpppFooter(); ?>
	    </div>
	    </form>
		<?php
	}
	
	/**
	 * Gets recheck data fro displaying auto upgrade information
	 */
	function dpppRecheckData($data='') {
		if ( $data != '' ) {
			update_option('dppp_version_check',$data);
		} else {
			$version_chk = get_option('dppp_version_check');
			return $version_chk;
		}
	}
	
	/**
	 * Extracts plugin update data
	 */
	function dpppExtractUpdateData() {
		$arr = array();
		$version_chk_file = "http://www.maxblogpress.com/plugin-updates/different-posts-per-page.php?v=".DPPP_VERSION;
		$content = wp_remote_fopen($version_chk_file);
		if ( $content ) {
			$content          = nl2br($content);
			$content_arr      = explode('<br />', $content);
			$latest_version   = trim(trim(strstr($content_arr[0],'~'),'~'));
			$recheck_interval = trim(trim(strstr($content_arr[1],'~'),'~'));
			$download_url     = trim(trim(strstr($content_arr[2],'~'),'~'));
			$msg_plugin_mgmt  = trim(trim(strstr($content_arr[3],'~'),'~'));
			$msg_in_plugin    = trim(trim(strstr($content_arr[4],'~'),'~'));
			$upgrade_url      = $this->dppp_siteurl.'/wp-admin/options-general.php?page='.$this->dppp_path.'&action=upgrade&dnl='.$download_url;
			$arr = array($latest_version, $recheck_interval, $download_url, $msg_plugin_mgmt, $msg_in_plugin, $upgrade_url);
		}
		return $arr;
	}
	
	/**
	 * Interface for upgrading plugin
	 */
	function dpppUpgradePlugin() {
		global $wp_version;
		$plugin = $this->dppp_path;
		echo '<div class="wrap">';
		$this->dpppHeader();
		echo '<h3>Upgrade Plugin &raquo;</h3>';
		if ( $wp_version >= 2.5 ) {
			$res = $this->dpppDoPluginUpgrade($plugin);
		} else {
			echo '&raquo; Wordpress 2.5 or higher required for automatic upgrade.<br><br>';
		}
		if ( $res == false ) echo '&raquo; Plugin couldn\'t be upgraded.<br><br>';
		echo '<br><strong><a href="'.$this->dppp_siteurl.'/wp-admin/plugins.php">Go back to plugins page</a> | <a href="'.$this->dppp_siteurl.'/wp-admin/options-general.php?page='.$this->dppp_path.'">'.DPPP_NAME.' home page</a></strong>';
		$this->dpppFooter();
		echo '</div>';
		include('admin-footer.php');
	}
	
	/**
	 * Carries out plugin upgrade
	 */
	function dpppDoPluginUpgrade($plugin) {
		set_time_limit(300);
		global $wp_filesystem;
		$debug = 0;
		$was_activated = is_plugin_active($plugin); // Check current status of the plugin to retain the same after the upgrade

		// Is a filesystem accessor setup?
		if ( ! $wp_filesystem || !is_object($wp_filesystem) ) {
			WP_Filesystem();
		}
		if ( ! is_object($wp_filesystem) ) {
			echo '&raquo; Could not access filesystem.<br /><br />';
			return false;
		}
		if ( $wp_filesystem->errors->get_error_code() ) {
			echo '&raquo; Filesystem error '.$wp_filesystem->errors.'<br /><br />';
			return false;
		}
		
		if ( $debug ) echo '> File System Okay.<br /><br />';
		
		// Get the URL to the zip file
		$package = $_GET['dnl'];
		if ( empty($package) ) {
			echo '&raquo; Upgrade package not available.<br /><br />';
			return false;
		}
		// Download the package
		$file = download_url($package);
		if ( is_wp_error($file) || $file == '' ) {
			echo '&raquo; Download failed. '.$file->get_error_message().'<br /><br />';
			return false;
		}
		$working_dir = $this->dppp_abspath . 'wp-content/upgrade/' . basename($plugin, '.php');
		
		if ( $debug ) echo '> Working Directory = '.$working_dir.'<br /><br />';
		
		// Unzip package to working directory
		$result = $this->dpppUnzipFile($file, $working_dir);
		if ( is_wp_error($result) ) {
			unlink($file);
			$wp_filesystem->delete($working_dir, true);
			echo '&raquo; Couldn\'t unzip package to working directory. Make sure that "/wp-content/upgrade/" folder has write permission (CHMOD 755).<br /><br />';
			return $result;
		}
		
		if ( $debug ) echo '> Unzip package to working directory successful<br /><br />';
		
		// Once extracted, delete the package
		unlink($file);
		if ( is_plugin_active($plugin) ) {
			deactivate_plugins($plugin, true); //Deactivate the plugin silently, Prevent deactivation hooks from running.
		}
		
		// Remove the old version of the plugin
		$plugin_dir = dirname($this->dppp_abspath . PLUGINDIR . "/$plugin");
		$plugin_dir = trailingslashit($plugin_dir);
		// If plugin is in its own directory, recursively delete the directory.
		if ( strpos($plugin, '/') && $plugin_dir != $base . PLUGINDIR . '/' ) {
			$deleted = $wp_filesystem->delete($plugin_dir, true);
		} else {

			$deleted = $wp_filesystem->delete($base . PLUGINDIR . "/$plugin");
		}
		if ( !$deleted ) {
			$wp_filesystem->delete($working_dir, true);
			echo '&raquo; Could not remove the old plugin. Make sure that "/wp-content/plugins/" folder has write permission (CHMOD 755).<br /><br />';
			return false;
		}
		
		if ( $debug ) echo '> Old version of the plugin removed successfully.<br /><br />';

		// Copy new version of plugin into place
		if ( !$this->dpppCopyDir($working_dir, $this->dppp_abspath . PLUGINDIR) ) {
			echo '&raquo; Installation failed. Make sure that "/wp-content/plugins/" folder has write permission (CHMOD 755)<br /><br />';
			return false;
		}
		//Get a list of the directories in the working directory before we delete it, we need to know the new folder for the plugin
		$filelist = array_keys( $wp_filesystem->dirlist($working_dir) );
		// Remove working directory
		$wp_filesystem->delete($working_dir, true);
		// if there is no files in the working dir
		if( empty($filelist) ) {
			echo '&raquo; Installation failed.<br /><br />';
			return false; 
		}
		$folder = $filelist[0];
		$plugin = get_plugins('/' . $folder);      // Pass it with a leading slash, search out the plugins in the folder, 
		$pluginfiles = array_keys($plugin);        // Assume the requested plugin is the first in the list
		$result = $folder . '/' . $pluginfiles[0]; // without a leading slash as WP requires
		
		if ( $debug ) echo '> Copy new version of plugin into place successfully.<br /><br />';
		
		if ( is_wp_error($result) ) {
			echo '&raquo; '.$result.'<br><br>';
			return false;
		} else {
			//Result is the new plugin file relative to PLUGINDIR
			echo '&raquo; Plugin upgraded successfully<br><br>';	
			if( $result && $was_activated ){
				echo '&raquo; Attempting reactivation of the plugin...<br><br>';	
				echo '<iframe style="display:none" src="' . wp_nonce_url('update.php?action=activate-plugin&plugin=' . $result, 'activate-plugin_' . $result) .'"></iframe>';
				sleep(15);
				echo '&raquo; Plugin reactivated successfully.<br><br>';	
			}
			return true;
		}
	}
	
	/**
	 * Copies directory from given source to destinaktion
	 */
	function dpppCopyDir($from, $to) {
		global $wp_filesystem;
		$dirlist = $wp_filesystem->dirlist($from);
		$from = trailingslashit($from);
		$to = trailingslashit($to);
		foreach ( (array) $dirlist as $filename => $fileinfo ) {
			if ( 'f' == $fileinfo['type'] ) {
				if ( ! $wp_filesystem->copy($from . $filename, $to . $filename, true) ) return false;
				$wp_filesystem->chmod($to . $filename, 0644);
			} elseif ( 'd' == $fileinfo['type'] ) {
				if ( !$wp_filesystem->mkdir($to . $filename, 0755) ) return false;
				if ( !$this->dpppCopyDir($from . $filename, $to . $filename) ) return false;
			}
		}
		return true;
	}
	
	/**
	 * Unzips the file to given directory
	 */
	function dpppUnzipFile($file, $to) {
		global $wp_filesystem;
		if ( ! $wp_filesystem || !is_object($wp_filesystem) )
			return new WP_Error('fs_unavailable', __('Could not access filesystem.'));
		$fs =& $wp_filesystem;
		require_once(ABSPATH . 'wp-admin/includes/class-pclzip.php');
		$archive = new PclZip($file);
		// Is the archive valid?
		if ( false == ($archive_files = $archive->extract(PCLZIP_OPT_EXTRACT_AS_STRING)) )
			return new WP_Error('incompatible_archive', __('Incompatible archive'), $archive->errorInfo(true));
		if ( 0 == count($archive_files) )
			return new WP_Error('empty_archive', __('Empty archive'));
		$to = trailingslashit($to);
		$path = explode('/', $to);
		$tmppath = '';
		for ( $j = 0; $j < count($path) - 1; $j++ ) {
			$tmppath .= $path[$j] . '/';
			if ( ! $fs->is_dir($tmppath) )
				$fs->mkdir($tmppath, 0755);
		}
		foreach ($archive_files as $file) {
			$path = explode('/', $file['filename']);
			$tmppath = '';
			// Loop through each of the items and check that the folder exists.
			for ( $j = 0; $j < count($path) - 1; $j++ ) {
				$tmppath .= $path[$j] . '/';
				if ( ! $fs->is_dir($to . $tmppath) )
					if ( !$fs->mkdir($to . $tmppath, 0755) )
						return new WP_Error('mkdir_failed', __('Could not create directory'));
			}
			// We've made sure the folders are there, so let's extract the file now:
			if ( ! $file['folder'] )
				if ( !$fs->put_contents( $to . $file['filename'], $file['content']) )
					return new WP_Error('copy_failed', __('Could not copy file'));
				$fs->chmod($to . $file['filename'], 0755);
		}
		return true;
	}
	
	/**
	 * Plugin registration form
	 * @access public 
	 */
	function dpppRegistrationForm($form_name, $submit_btn_txt='Register', $name, $email, $hide=0, $submit_again='') {
		$wp_url = get_bloginfo('wpurl');
		$wp_url = (strpos($wp_url,'http://') === false) ? get_bloginfo('siteurl') : $wp_url;
		$thankyou_url = $wp_url.'/wp-admin/options-general.php?page='.$_GET['page'];
		$onlist_url   = $wp_url.'/wp-admin/options-general.php?page='.$_GET['page'].'&amp;mbp_onlist=1';
		if ( $hide == 1 ) $align_tbl = 'left';
		else $align_tbl = 'center';
		?>
		
		<?php if ( $submit_again != 1 ) { ?>
		<script><!--
		function trim(str){
			var n = str;
			while ( n.length>0 && n.charAt(0)==' ' ) 
				n = n.substring(1,n.length);
			while( n.length>0 && n.charAt(n.length-1)==' ' )	
				n = n.substring(0,n.length-1);
			return n;
		}
		function dpppValidateForm_0() {
			var name = document.<?php echo $form_name;?>.name;
			var email = document.<?php echo $form_name;?>.from;
			var reg = /^([A-Za-z0-9_\-\.])+\@([A-Za-z0-9_\-\.])+\.([A-Za-z]{2,4})$/;
			var err = ''
			if ( trim(name.value) == '' )
				err += '- Name Required\n';
			if ( reg.test(email.value) == false )
				err += '- Valid Email Required\n';
			if ( err != '' ) {
				alert(err);
				return false;
			}
			return true;
		}
		//-->
		</script>
		<?php } ?>
		<table align="<?php echo $align_tbl;?>">
		<form name="<?php echo $form_name;?>" method="post" action="http://www.aweber.com/scripts/addlead.pl" <?php if($submit_again!=1){;?>onsubmit="return dpppValidateForm_0()"<?php }?>>
		 <input type="hidden" name="unit" value="maxbp-activate">
		 <input type="hidden" name="redirect" value="<?php echo $thankyou_url;?>">
		 <input type="hidden" name="meta_redirect_onlist" value="<?php echo $onlist_url;?>">
		 <input type="hidden" name="meta_adtracking" value="dppp-w-activate">
		 <input type="hidden" name="meta_message" value="1">
		 <input type="hidden" name="meta_required" value="from,name">
	 	 <input type="hidden" name="meta_forward_vars" value="1">	
		 <?php if ( $submit_again == 1 ) { ?> 	
		 <input type="hidden" name="submit_again" value="1">
		 <?php } ?>		 
		 <?php if ( $hide == 1 ) { ?> 
		 <input type="hidden" name="name" value="<?php echo $name;?>">
		 <input type="hidden" name="from" value="<?php echo $email;?>">
		 <?php } else { ?>
		 <tr><td>Name: </td><td><input type="text" name="name" value="<?php echo $name;?>" size="25" maxlength="150" /></td></tr>
		 <tr><td>Email: </td><td><input type="text" name="from" value="<?php echo $email;?>" size="25" maxlength="150" /></td></tr>
		 <?php } ?>
		 <tr><td>&nbsp;</td><td><input type="submit" name="submit" value="<?php echo $submit_btn_txt;?>" class="button" /></td></tr>
		</form>
		</table>
		<?php
	}
	
	/**
	 * Register Plugin - Step 2
	 * @access public 
	 */
	function dpppRegister_2($form_name='frm2',$name,$email) {
		$msg = 'You have not clicked on the confirmation link yet. A confirmation email has been sent to you again. Please check your email and click on the confirmation link to activate the plugin.';
		if ( trim($_GET['submit_again']) != '' && $msg != '' ) {
			echo '<div id="message" class="updated fade"><p><strong>'.$msg.'</strong></p></div>';
		}
		?>
		<div class="wrap"><h2> <?php echo DPPP_NAME.' '.DPPP_VERSION; ?></h2>
		 <center>
		 <table width="640" cellpadding="5" cellspacing="1" bgcolor="#ffffff" style="border:1px solid #e9e9e9">
		  <tr><td align="center"><h3>Almost Done....</h3></td></tr>
		  <tr><td><h3>Step 1:</h3></td></tr>
		  <tr><td>A confirmation email has been sent to your email "<?php echo $email;?>". You must click on the link inside the email to activate the plugin.</td></tr>
		  <tr><td><strong>The confirmation email will look like:</strong><br /><img src="http://www.maxblogpress.com/images/activate-plugin-email.jpg" vspace="4" border="0" /></td></tr>
		  <tr><td>&nbsp;</td></tr>
		  <tr><td><h3>Step 2:</h3></td></tr>
		  <tr><td>Click on the button below to Verify and Activate the plugin.</td></tr>
		  <tr><td><?php $this->dpppRegistrationForm($form_name.'_0','Verify and Activate',$name,$email,$hide=1,$submit_again=1);?></td></tr>
		 </table>
		 <p>&nbsp;</p>
		 <table width="640" cellpadding="5" cellspacing="1" bgcolor="#ffffff" style="border:1px solid #e9e9e9">
           <tr><td><h3>Troubleshooting</h3></td></tr>
           <tr><td><strong>The confirmation email is not there in my inbox!</strong></td></tr>
           <tr><td>Dont panic! CHECK THE JUNK, spam or bulk folder of your email.</td></tr>
           <tr><td>&nbsp;</td></tr>
           <tr><td><strong>It's not there in the junk folder either.</strong></td></tr>
           <tr><td>Sometimes the confirmation email takes time to arrive. Please be patient. WAIT FOR 6 HOURS AT MOST. The confirmation email should be there by then.</td></tr>
           <tr><td>&nbsp;</td></tr>
           <tr><td><strong>6 hours and yet no sign of a confirmation email!</strong></td></tr>
           <tr><td>Please register again from below:</td></tr>
           <tr><td><?php $this->dpppRegistrationForm($form_name,'Register Again',$name,$email,$hide=0,$submit_again=2);?></td></tr>
           <tr><td><strong>Help! Still no confirmation email and I have already registered twice</strong></td></tr>
           <tr><td>Okay, please register again from the form above using a DIFFERENT EMAIL ADDRESS this time.</td></tr>
           <tr><td>&nbsp;</td></tr>
           <tr>
             <td><strong>Why am I receiving an error similar to the one shown below?</strong><br />
                 <img src="http://www.maxblogpress.com/images/no-verification-error.jpg" border="0" vspace="8" /><br />
               You get that kind of error when you click on &quot;Verify and Activate&quot; button or try to register again.<br />
               <br />
               This error means that you have already subscribed but have not yet clicked on the link inside confirmation email. In order to  avoid any spam complain we don't send repeated confirmation emails. If you have not recieved the confirmation email then you need to wait for 12 hours at least before requesting another confirmation email. </td>
           </tr>
           <tr><td>&nbsp;</td></tr>
           <tr><td><strong>But I've still got problems.</strong></td></tr>
           <tr><td>Stay calm. <strong><a href="http://www.maxblogpress.com/contact-us/" target="_blank">Contact us</a></strong> about it and we will get to you ASAP.</td></tr>
         </table>
		 </center>		
		<p style="text-align:center;margin-top:3em;"><strong><?php echo DPPP_NAME.' '.DPPP_VERSION; ?> by <a href="http://www.maxblogpress.com/" target="_blank" >MaxBlogPress</a></strong></p>
	    </div>
		<?php
	}

	/**
	 * Register Plugin - Step 1
	 * @access public 
	 */
	function dpppRegister_1($form_name='frm1') {
		global $userdata;
		$name  = trim($userdata->first_name.' '.$userdata->last_name);
		$email = trim($userdata->user_email);
		?>
		<div class="wrap"><h2> <?php echo DPPP_NAME.' '.DPPP_VERSION; ?></h2>
		 <center>
		 <table width="620" cellpadding="3" cellspacing="1" bgcolor="#ffffff" style="border:1px solid #e9e9e9">
		  <tr><td align="center"><h3>Please register the plugin to activate it. (Registration is free)</h3></td></tr>
		  <tr><td align="left">In addition you'll receive complimentary subscription to MaxBlogPress Newsletter which will give you many tips and tricks to attract lots of visitors to your blog.</td></tr>
		  <tr><td align="center"><strong>Fill the form below to register the plugin:</strong></td></tr>
		  <tr><td><?php $this->dpppRegistrationForm($form_name,'Register',$name,$email);?></td></tr>
		  <tr><td align="center"><font size="1">[ Your contact information will be handled with the strictest confidence <br />and will never be sold or shared with third parties ]</font></td></td></tr>
		 </table>
		 </center>
		<p style="text-align:center;margin-top:3em;"><strong><?php echo DPPP_NAME.' '.DPPP_VERSION; ?> by <a href="http://www.maxblogpress.com/" target="_blank" >MaxBlogPress</a></strong></p>
	    </div>
		<?php
	}
	
} // Eof Class

$DPPP = new DPPP();
?>